@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2021-08-18 18:13:15
+@LastEditTime: 2021-08-25 09:24:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -136,7 +136,7 @@ class LaunchGoodsListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 10))
         launch_base_model = LaunchBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.launch_goods_list(app_id, act_id, page_size, page_index, self.get_taobao_param().access_token, app_key, app_secret)
+        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, self.get_taobao_param().access_token, app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
