@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-08-31 09:08:45
+@LastEditTime: 2021-09-06 10:00:51
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -18,88 +18,125 @@ class QueueUpHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def _get_zset_name(self, queue_name):
+    def _get_zset_name(self,app_id,queue_name):
         """
         :description: 获取排行集合名称，集合用于排行榜，排第一的优先操作
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
         zset_name = "queueup_zset"
+        if app_id:
+            zset_name += "_" + str(app_id)
         if queue_name:
             zset_name += ":" + str(queue_name)
         return zset_name
 
     @classmethod
-    def _get_count_name(self, queue_name):
+    def _get_count_name(self,app_id, queue_name):
         """
         :description: 获取排队号计数名称
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
         count_name = "queueup_count"
+        if app_id:
+            count_name += "_" + str(app_id)
         if queue_name:
             count_name += ":" + str(SevenHelper.get_now_day_int()) + "_" + str(queue_name)
         return count_name
 
     @classmethod
-    def _get_user_hash_name(self):
+    def _get_user_hash_name(self, app_id):
         """
         :description: 获取用户关联队列名称
+        :param app_id：应用标识
         :return: 
         :last_editors: HuangJianYi
         """
-        return "queueup_user_list"
+        hash_name = "queueup_user_list"
+        if app_id:
+            hash_name += "_" + str(app_id)
+        return hash_name
 
     @classmethod
-    def _get_queue_no(self, queue_name):
+    def _get_user_zset_name(self,app_id):
+        """
+        :description: 用户在小程序内的排队次数信息
+        :param app_id：应用标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        zset_name = "queueup_zset_user"
+        if app_id:
+            zset_name += "_" + str(app_id)
+        return zset_name
+
+    @classmethod
+    def _get_queue_no(self, app_id, queue_name):
         """
         :description: 获取排队号
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
-        count_name = self._get_count_name(queue_name)
+        count_name = self._get_count_name(app_id,queue_name)
         redis_init = SevenHelper.redis_init()
         queue_no = redis_init.incr(count_name, 1)
         redis_init.expire(count_name, 24 * 3600)
         return queue_no
 
     @classmethod
-    def _get_queue_num(self, queue_name):
+    def _get_queue_num(self, app_id, queue_name):
         """
         :description: 获取当前排队人数
-        :param act_id：活动标识
-        :param module_id：活动模块标识
+        :param app_id：应用标识
+        :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
-        zset_name = self._get_zset_name(queue_name)
+        zset_name = self._get_zset_name(app_id,queue_name)
         redis_init = SevenHelper.redis_init()
         return redis_init.zcard(zset_name)
 
     @classmethod
-    def _delete_user(self, queue_name):
+    def _get_all_queue_num(self, app_id):
+        """
+        :description: 获取小程序总排队人数
+        :param app_id：应用标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        user_zset_name = self._get_user_zset_name(app_id)
+        redis_init = SevenHelper.redis_init()
+        return redis_init.zcount(user_zset_name,1,5000)
+
+    @classmethod
+    def _delete_user(self, app_id, queue_name):
         """
         :description: 删除第一位未确认的排队者
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if SevenHelper.is_continue_request(f"queue_delete_user:{queue_name}", 500) == True:
+        if SevenHelper.is_continue_request(f"queue_delete_user:{queue_name}", 200) == True:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "对不起,请500毫秒后再试"
+            invoke_result_data.error_message = "对不起,请200毫秒后再试"
             return invoke_result_data
         try:
             redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(queue_name)
+            zset_name = self._get_zset_name(app_id, queue_name)
             value_list = redis_init.zrange(zset_name, 0, 0)
             if len(value_list) > 0:
                 data = value_list[0]
-                hash_name = self._get_user_hash_name()
+                hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
                 if hash_value:
@@ -131,21 +168,23 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def _delete_and_notice_user(self, queue_name):
+    def _delete_and_notice_user(self, app_id, queue_name):
         """
         :description: 删除第一位未确认的排队者并通知下一位开始确认
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
-        invoke_result_data = self._delete_user(queue_name)
+        invoke_result_data = self._delete_user(app_id,queue_name)
         if invoke_result_data.error_code == "del":
-            self._delete_user(queue_name)
+            self._delete_user(app_id,queue_name)
 
     @classmethod
-    def clear(self, queue_name):
+    def clear(self, app_id, queue_name):
         """
         :description: 清空排队
+        :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
@@ -153,8 +192,8 @@ class QueueUpHelper:
         invoke_result_data = InvokeResultData()
         try:
             redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(queue_name)
-            hash_name = self._get_user_hash_name()
+            zset_name = self._get_zset_name(app_id,queue_name)
+            hash_name = self._get_user_hash_name(app_id)
             zset_result = redis_init.delete(zset_name)
             hash_result = 1
             match_result = redis_init.hscan_iter(hash_name, match=f'*_queuename_{queue_name}')
@@ -180,14 +219,15 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def queue(self, queue_name, user_id, user_nick="", queue_length=10):
+    def queue(self, app_id, queue_name, user_id, user_nick="", queue_length=10, all_queue_limit_num=500):
         """
         :description: 加入排队
-        :param act_id：活动标识
+        :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id 用户标识
         :param user_nick 用户昵称
         :param queue_length：队列的长度
+        :param all_queue_limit_num：小程序内总排队人数上限
         :return: 
         :last_editors: HuangJianYi
         """
@@ -200,21 +240,30 @@ class QueueUpHelper:
                 invoke_result_data.error_code = "acquire_lock"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
-
-            zset_name = self._get_zset_name(queue_name)
-            data = str(user_id)
             redis_init = SevenHelper.redis_init()
+            if all_queue_limit_num > 0 and self._get_all_queue_num(app_id) >= all_queue_limit_num:
+                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "排队失败,超过排队人数上限"
+                return invoke_result_data
+            zset_name = self._get_zset_name(app_id,queue_name)
+            data = str(user_id)
             if not redis_init.zscore(zset_name, data):
-                if self._get_queue_num(queue_name) >= queue_length:
+                if self._get_queue_num(app_id,queue_name) >= queue_length:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "limit"
                     invoke_result_data.error_message = "当前排队人数已达上限"
                     return invoke_result_data
-                queue_no = self._get_queue_no(queue_name)
+                queue_no = self._get_queue_no(app_id,queue_name)
                 redis_init.zadd(zset_name, {data: queue_no})
                 redis_init.expire(zset_name, 7 * 24 * 3600)
 
+                user_zset_name = self._get_user_zset_name(app_id)
+                redis_init.zincrby(user_zset_name, 1, data)
+                redis_init.expire(user_zset_name, 7 * 24 * 3600)
+
                 hash_value = {}
                 hash_value["queue_name"] = queue_name  #排队名称
                 hash_value["queue_no"] = queue_no  #排队号
@@ -235,17 +284,18 @@ class QueueUpHelper:
                 else:
                     hash_value["progress_status"] = 0
                 #添加排队信息
-                hash_name = self._get_user_hash_name()
+                hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 redis_init.hsetnx(hash_name, hash_key, SevenHelper.json_dumps(hash_value))
                 redis_init.expire(hash_name, 7 * 24 * 3600)
 
                 result_data = {}
                 result_data["queue_no"] = hash_value["queue_no"]  #排队号
-                result_data["queue_num"] = self._get_queue_num(queue_name)  #当前排队人数
+                result_data["queue_num"] = self._get_queue_num(app_id,queue_name)  #当前排队人数
                 result_data["queue_index"] = queue_index  #当前位置
                 result_data["before_num"] = queue_index - 1  #排在前面的人数
                 invoke_result_data.data = result_data
+
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 return invoke_result_data
             else:
@@ -263,9 +313,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def pop(self, queue_name, user_id):
+    def pop(self, app_id, queue_name, user_id):
         """
         :description: 退出排队
+        :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id 用户标识
         :return: 
@@ -273,12 +324,13 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         try:
-            zset_name = self._get_zset_name(queue_name)
+            zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
             redis_init = SevenHelper.redis_init()
             if redis_init.zscore(zset_name, data):
                 redis_init.zrem(zset_name, data)
-                redis_init.hdel(self._get_user_hash_name(), f"userid_{data}_queuename_{queue_name}")
+                redis_init.zincrby(self._get_user_zset_name(app_id), -1, data)
+                redis_init.hdel(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
                 return invoke_result_data
             else:
                 invoke_result_data.success = False
@@ -293,9 +345,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def query(self, queue_name, user_id):
+    def query(self, app_id, queue_name, user_id):
         """
         :description: 查询某用户排队情况
+        :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
         :return: 
@@ -304,10 +357,12 @@ class QueueUpHelper:
         invoke_result_data = InvokeResultData()
         try:
             redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(queue_name)
+            zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
-
-            self._delete_and_notice_user(queue_name)
+            #踢掉过期用户并通知下一个用户
+            self._delete_and_notice_user(app_id,queue_name)
+            #删除用户排队次数小于等于0的数据
+            redis_init.zremrangebyscore(self._get_user_zset_name(app_id),-10,0)
 
             #判断是否存在排队信息
             score = redis_init.zscore(zset_name, data)
@@ -315,10 +370,10 @@ class QueueUpHelper:
                 query_user = {}
                 query_user["queue_name"] = queue_name  #队列名称
                 query_user["queue_no"] = int(score)  #排队号
-                query_user["total_num"] = self._get_queue_num(queue_name)  #总排队人数
+                query_user["total_num"] = self._get_queue_num(app_id,queue_name)  #总排队人数
                 query_user["queue_index"] = int(redis_init.zrank(zset_name, data)) + 1  #当前位置
                 query_user["before_num"] = query_user["queue_index"] - 1  #排在前面的人数
-                hash_value = redis_init.hget(self._get_user_hash_name(), f"userid_{data}_queuename_{queue_name}")
+                hash_value = redis_init.hget(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
                 hash_value = SevenHelper.json_loads(hash_value) if hash_value else {}
                 query_user["start_date"] = hash_value["start_date"] if hash_value.__contains__("start_date") else ''
                 query_user["end_date"] = hash_value["end_date"] if hash_value.__contains__("end_date") else ''
@@ -330,7 +385,7 @@ class QueueUpHelper:
                 query_user = {}
                 query_user["queue_name"] = queue_name  #队列名称
                 query_user["progress_status"] = -1  #进度-1未排队0已排队1已确认2办理中
-                query_user["before_num"] = self._get_queue_num(queue_name)  #排在前面的人数
+                query_user["before_num"] = self._get_queue_num(app_id,queue_name)  #排在前面的人数
                 invoke_result_data.data = query_user
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -344,9 +399,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def muti_user_query(self, user_id):
+    def muti_user_query(self, app_id, user_id):
         """
         :description: 批量查询某用户排队情况
+        :param app_id：应用标识
         :param user_id：用户标识
         :return: 
         :last_editors: HuangJianYi
@@ -355,12 +411,12 @@ class QueueUpHelper:
         invoke_result_data.data = []
         try:
             redis_init = SevenHelper.redis_init()
-            hash_name = self._get_user_hash_name()
+            hash_name = self._get_user_hash_name(app_id)
             data = str(user_id)
             match_result = redis_init.hscan_iter(hash_name, match=f'userid_{data}_*')
             for item in match_result:
                 hash_value = SevenHelper.json_loads(item[1])
-                query_invoke_result_data = self.query(hash_value["queue_name"], user_id)
+                query_invoke_result_data = self.query(app_id,hash_value["queue_name"], user_id)
                 if query_invoke_result_data.success == True:
                     invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
@@ -372,9 +428,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def muti_queue_query(self, queue_name_list, user_id):
+    def muti_queue_query(self, app_id, queue_name_list, user_id):
         """
         :description: 批量查询排队情况
+        :param app_id：应用标识
         :param queue_name_list：查询队列集合
         :param user_id：用户标识
         :return: 
@@ -384,7 +441,7 @@ class QueueUpHelper:
         invoke_result_data.data = []
         try:
             for queue_name in queue_name_list:
-                query_invoke_result_data = self.query(queue_name, user_id)
+                query_invoke_result_data = self.query(app_id,queue_name, user_id)
                 invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
         except Exception as ex:
@@ -395,9 +452,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def update_time(self, queue_name, user_id, operate_time=0):
+    def update_time(self, app_id, queue_name, user_id, operate_time=0):
         """
         :description: 更新可操作时间，用于操作倒计时，时间到则踢出队列
+        :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
         :param operate_time：增加的操作时间，单位秒
@@ -407,11 +465,11 @@ class QueueUpHelper:
         invoke_result_data = InvokeResultData()
         try:
             redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(queue_name)
+            zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
             score = redis_init.zscore(zset_name, data)
             if score and operate_time > 0:
-                hash_name = self._get_user_hash_name()
+                hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
                 if not hash_value:
@@ -433,9 +491,10 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def sign(self, queue_name, user_id, quit_other_queue=True):
+    def sign(self,app_id, queue_name, user_id, quit_other_queue=True):
         """
         :description: 签到操作（证明排队的人做出应答，开始办理业务，更新开始操作时间并且将当前用户在其他队列中踢掉）
+        :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
         :param quit_other_queue：是否退出其他正在排队的队列，True是False否
@@ -445,7 +504,7 @@ class QueueUpHelper:
         invoke_result_data = InvokeResultData()
         try:
             redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(queue_name)
+            zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
             #判断是否存在排队信息
             score = redis_init.zscore(zset_name, data)
@@ -458,7 +517,7 @@ class QueueUpHelper:
                     return invoke_result_data
                 start_timestamp = TimeHelper.get_now_timestamp()
                 end_timestamp = start_timestamp + int(config.get_value("queue_operate_time", 300))  #操作时间，单位秒
-                hash_name = self._get_user_hash_name()
+                hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
                 if not hash_value:
@@ -480,7 +539,7 @@ class QueueUpHelper:
                         hash_value = SevenHelper.json_loads(item[1])
                         if hash_value["queue_name"] == queue_name:
                             continue
-                        self.pop(hash_value["queue_name"], data)
+                        self.pop(app_id,hash_value["queue_name"], data)
                 invoke_result_data.data = hash_value
                 return invoke_result_data
             else:
