@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-08-25 09:31:21
+@LastEditTime: 2021-09-01 16:08:19
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -482,3 +482,17 @@ class SevenHelper:
             return json.loads(rep_str)
         except Exception as ex:
             return json.loads(self.json_dumps(rep_str))
+    @classmethod
+    def get_sub_table(self,object_id,sub_count=0):
+        """
+        :description: 获取分表名称
+        :param object_id:对象标识
+        :param sub_count:分表数量
+        :return:
+        :last_editors: HuangJianYi
+        """
+        sub_table = None
+        if not sub_count:
+            return sub_table
+        sub_table = str(object_id % sub_count)
+        return sub_table
