@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-08-19 16:12:52
+@LastEditTime: 2021-08-25 09:35:06
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,7 +20,7 @@ from seven_framework.base_model import *
 
 class WeChatHelper:
     """
-    :description: 微信帮助类
+    :description: 微信帮助类 1.临时登录凭证校验获取open_id、session_key  2.解析加密数据
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
@@ -456,5 +456,8 @@ class WeChatRefundReponse(object):
         return WeChatHelper.array_to_xml(dict(return_code=code, return_msg=msg))
 
 class WeixinError(Exception):
+    """
+    :description: 微信异常类
+    """
     def __init__(self, msg):
         super(WeixinError, self).__init__(msg)
\ No newline at end of file
