@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-08-19 18:04:16
+@LastEditTime: 2021-08-26 10:28:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,7 +20,7 @@ from seven_cloudapp_frame.models.db_models.version.version_info_model import *
 
 class AppBaseModel():
     """
-    :description: 应用信息基类
+    :description: 应用信息业务模型
     """
     def __init__(self, context):
         self.context = context
