@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2021-08-19 22:02:43
+@LastEditTime: 2021-09-03 10:20:56
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -40,3 +40,9 @@ class TaskType(Enum):
     collect_goods = 8
     # 浏览商品，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""}
     browse_goods = 9
+    # 浏览店铺，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}]
+    browse_store = 10
+    # 浏览直播间，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}]
+    browse_live_room = 11
+    # 浏览会场/专题，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}]
+    browse_special_topic = 12
