@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-02 14:07:35
+@LastEditTime: 2021-09-03 18:00:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -460,20 +460,22 @@ class OrderBaseModel(FrameBaseModel):
         redis_init = SevenHelper.redis_init()
         pay_order_cache_key = f"sub_pay_order_no_list:appid_{app_id}_userid_{user_id}"
         pay_order_no_list = redis_init.lrange(pay_order_cache_key,0,-1)
+        pay_order_list = []
         is_add = False
         if not pay_order_no_list or len(pay_order_no_list)<=0:
             tao_pay_order_model = TaoPayOrderModel(context=self.context)
             pay_order_list = tao_pay_order_model.get_dict_list("app_id=%s and user_id=%s",field="sub_pay_order_no", params=[app_id,user_id])
             is_add = True
             
-        for item in pay_order_list:
-            pay_order_no_list.append(item["sub_pay_order_no"])
-            if is_add == True:
-                redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
-                redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
+        if len(pay_order_list) >0:
+            for item in pay_order_list:
+                pay_order_no_list.append(item["sub_pay_order_no"])
+                if is_add == True:
+                    redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
+                    redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
         return pay_order_no_list,redis_init,pay_order_cache_key
 
-    def sync_tao_pay_order(self,app_id,act_id,module_id,user_id,login_token,handler_name,request_code,asset_type=3,goods_id="",sku_id="",ascription_type=1,app_key="",app_secret="",is_log=False,check_user_nick=True,continue_request_expire=5,asset_sub_table=None):
+    def sync_tao_pay_order(self,app_id,act_id,module_id,user_id,login_token,handler_name,request_code,asset_type=3,goods_id="",sku_id="",ascription_type=1,app_key="",app_secret="",is_log=False,check_user_nick=True,continue_request_expire=5):
         """
         :description: 同步淘宝支付订单给用户加资产
         :param app_id:应用标识
@@ -492,7 +494,6 @@ class OrderBaseModel(FrameBaseModel):
         :param is_log:是否记录top请求日志
         :param check_user_nick:是否校验昵称为空
         :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒
-        :param asset_sub_table:资产分表名称
         :return 
         :last_editors: HuangJianYi
         """
@@ -529,7 +530,7 @@ class OrderBaseModel(FrameBaseModel):
                     all_order_list = []
                     if asset_type == 3:
                         price_base_model = PriceBaseModel(context=self.context)
-                        price_gear_dict_list = price_base_model.get_price_gear_list(app_id,act_id,100,0)
+                        price_gear_dict_list = price_base_model.get_price_gear_list(app_id,act_id,100,0).data
                         for price_gear_dict in price_gear_dict_list:
                             goods_ids_list.append(price_gear_dict["goods_id"])
                     else:
@@ -575,7 +576,6 @@ class OrderBaseModel(FrameBaseModel):
                                         continue
                                         
                                 tao_pay_order = TaoPayOrder()
-                                tao_pay_order.id = f"{act_id}_{user_id}_{UUIDHelper.get_uuid()}"
                                 tao_pay_order.app_id = app_id
                                 tao_pay_order.act_id = act_id
                                 tao_pay_order.ascription_type = ascription_type
@@ -613,7 +613,7 @@ class OrderBaseModel(FrameBaseModel):
        
                             only_id =  f"sync_tao_pay_order_{handler_name}_{request_code}" if handler_name and request_code else ""
                             asset_base_model = AssetBaseModel(context=self.context)
-                            asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,buy_num,asset_object_id,1,"购买","",only_id,handler_name,request_code,info_json={},sub_table=asset_sub_table)
+                            asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,buy_num,asset_object_id,1,"购买","",only_id,handler_name,request_code,info_json={})
                             if asset_invoke_result_data.success == False:
                                 invoke_result_data.success = False
                                 invoke_result_data.error_code = "error"
@@ -621,7 +621,7 @@ class OrderBaseModel(FrameBaseModel):
                             else:
                                 invoke_result_data.data = {}
                                 for item in tao_pay_order_list:
-                                    redis_init.lpush(pay_order_cache_key,tao_pay_order.sub_pay_order_no)
+                                    redis_init.lpush(pay_order_cache_key,item.sub_pay_order_no)
                                     redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
                                 invoke_result_data.data["asset_type"] = asset_type
                                 invoke_result_data.data["asset_object_id"] = asset_object_id
@@ -640,6 +640,10 @@ class OrderBaseModel(FrameBaseModel):
                         invoke_result_data.success = False
                         invoke_result_data.error_code = "error"
                         invoke_result_data.error_message = "没有匹配订单"  
+                else:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "error"
+                    invoke_result_data.error_message = "没有订单"  
         except Exception as ex:
             self.context.logging_link_error("【同步淘宝支付订单】" + str(ex))
             invoke_result_data.success = False
