@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-08-26 10:30:05
+@LastEditTime: 2021-09-01 16:11:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,7 +20,7 @@ class StatBaseModel():
     def __init__(self, context):
         self.context = context
 
-    def add_stat(self, app_id, act_id, module_id, user_id, open_id, key_name, key_value, sub_table=None):
+    def add_stat(self, app_id, act_id, module_id, user_id, open_id, key_name, key_value):
         """
         :description: 添加上报
         :param app_id：应用标识
@@ -30,10 +30,10 @@ class StatBaseModel():
         :param open_id：open_id
         :param key_name：统计key
         :param key_value：统计value
-        :param sub_table：分表名称（是否分表由业务方决定）
         :return:
         :last_editors: HuangJianYi
         """
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
         stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
 
         stat_queue = StatQueue()
@@ -48,7 +48,7 @@ class StatBaseModel():
         stat_queue.process_date = SevenHelper.get_now_datetime()
         return stat_queue_model.add_entity(stat_queue)
 
-    def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, key_list_dict, sub_table=None):
+    def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, key_list_dict):
         """
         :description: 添加上报
         :param app_id：应用标识
@@ -57,10 +57,10 @@ class StatBaseModel():
         :param user_id：用户标识
         :param open_id：open_id
         :param key_list_dict:键值对字典
-        :param sub_table：分表名称（统计队列表是否分表由业务方决定）
         :return:
         :last_editors: HuangJianYi
         """
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
         stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
         stat_queue_list = []
         for key,value in key_list_dict.items():
