@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-09-01 16:12:50
+@LastEditTime: 2021-09-03 11:15:34
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -240,8 +240,9 @@ class TopBaseModel():
                         if sku["sku_id"] == sku_id:
                             props_name = [i for i in props_names if sku["properties"] in i]
                             if len(props_name) > 0:
-                                return props_name[0][(len(sku["properties"]) + 1):]
-                            invoke_result_data.data = sku["properties_name"].split(':')[1]
+                                invoke_result_data.data = props_name[0][(len(sku["properties"]) + 1):]
+                            else:
+                                invoke_result_data.data = sku["properties_name"].split(':')[1]
                             return invoke_result_data
             return invoke_result_data
         except Exception as ex:
