@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-08-26 10:30:26
+@LastEditTime: 2021-09-02 17:32:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -23,7 +23,7 @@ class UserBaseModel():
     def __init__(self, context):
         self.context = context
 
-    def _get_user_info_id(self, act_id, user_id):
+    def _get_user_info_id_md5(self, act_id, user_id):
         """
         :description: 生成用户信息唯一标识
         :param act_id：活动标识
@@ -35,28 +35,29 @@ class UserBaseModel():
             return 0
         return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
 
-    def get_user_info_dependency_key(self, act_id, id, open_id=""):
+    def get_user_info_dependency_key(self, act_id, id_md5, open_id=""):
         """
         :description: 获取用户信息缓存key
         :param user_info_id：用户信息标识
+        :param id_md5：用户md5标识
         :param open_id：open_id
         :return: 
         :last_editors: HuangJianYi
         """
-        if id:
-            return  f"user_info:actid_{act_id}_id_{id}"
+        if id_md5:
+            return  f"user_info:actid_{act_id}_idmd5_{id_md5}"
         else:
             return  f"user_info:actid_{act_id}_openid_{open_id}"
 
-    def _delete_user_info_cache(self,act_id,id):
+    def _delete_user_info_cache(self,act_id,id_md5):
         """
         :description: 删除用户信息缓存
         :param act_id：活动标识
-        :param id：用户信息标识
+        :param id_md5：用户md5标识
         :return: 
         :last_editors: HuangJianYi
         """
-        cache_key = self.get_user_info_dependency_key(act_id,id)
+        cache_key = self.get_user_info_dependency_key(act_id,id_md5)
         redis_init = SevenHelper.redis_init()
         redis_init.delete(cache_key)
 
@@ -74,13 +75,14 @@ class UserBaseModel():
         if not act_id or (not user_id and not open_id):
             return user_info_dict
         user_info_model = UserInfoModel(context=self.context)
-        id = self._get_user_info_id(act_id,user_id)
-        dependency_key = self.get_user_info_dependency_key(act_id,id,open_id)
-        if id:
+        id_md5 = self._get_user_info_id_md5(act_id,user_id)
+        dependency_key = self.get_user_info_dependency_key(act_id,id_md5,open_id)
+        if id_md5:
             if is_cache:
-                user_info_dict = user_info_model.get_cache_dict_by_id(id,dependency_key=dependency_key)
+                user_info_dict = user_info_model.get_cache_dict("id_md5=%s",params=[id_md5],dependency_key=dependency_key)
             else:
-                user_info_dict = user_info_model.get_dict_by_id(id)
+                
+                user_info_dict = user_info_model.get_dict("id_md5=%s",params=[id_md5])
         else:
             if is_cache:
                 user_info_dict = user_info_model.get_cache_dict(dependency_key=dependency_key,where="act_id=%s and open_id=%s", params=[act_id, open_id])
@@ -206,7 +208,7 @@ class UserBaseModel():
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
                 user_info = UserInfo()
-                user_info.id = self._get_user_info_id(act_id, user_account.id)
+                user_info.id_md5 = self._get_user_info_id_md5(act_id, user_account.id)
                 user_info.app_id = app_id
                 user_info.act_id = act_id
                 user_info.open_id = open_id
@@ -233,7 +235,7 @@ class UserBaseModel():
                 user_info.login_token = SevenHelper.get_random(16, 1)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar")
                 
-                self._delete_user_info_cache(user_info.act_id,user_info.id)
+                self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
                     
         except Exception as ex:
             self.context.logging_link_error("【获取或更新用户信息】" + str(ex))
@@ -259,7 +261,7 @@ class UserBaseModel():
         """
         invoke_result_data = InvokeResultData()
 
-        if not act_id or (not user_id and not open_id) or (user_nick == "" and avatar == ""):
+        if not act_id or (not user_id and not open_id):
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -289,7 +291,7 @@ class UserBaseModel():
                 user_info_dict["modify_date"] = SevenHelper.get_now_datetime()
                 user_info_model.update_table("user_nick=%s,avatar=%s,modify_date=%s,is_member_before=%s,is_favor_before=%s","id=%s",params=[user_info_dict["user_nick"],user_info_dict["avatar"],user_info_dict["modify_date"],user_info_dict["is_member_before"],user_info_dict["is_favor_before"],user_info_dict["id"]])
                 
-                self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id"])
+                self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
                 
                 update_sql = ""
                 params = []
@@ -319,9 +321,9 @@ class UserBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        id = self._get_user_info_id(act_id, user_id)
+        id_md5 = self._get_user_info_id_md5(act_id, user_id)
         user_info_model = UserInfoModel(context=self.context)
-        user_info = user_info_model.get_entity_by_id(id)
+        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -344,7 +346,7 @@ class UserBaseModel():
         user_info.modify_date = modify_date
         user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
         
-        self._delete_user_info_cache(user_info.act_id,user_info.id)
+        self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         return invoke_result_data
 
@@ -359,12 +361,12 @@ class UserBaseModel():
         """
         invoke_result_data = InvokeResultData()
 
-        id = self._get_user_info_id(act_id, user_id)
+        id_md5 = self._get_user_info_id_md5(act_id, user_id)
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         user_info_model = UserInfoModel(db_transaction=db_transaction,context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
-        user_info = user_info_model.get_entity_by_id(id)
+        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -414,7 +416,7 @@ class UserBaseModel():
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
             
-            self._delete_user_info_cache(user_info.act_id,user_info.id)
+            self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         except Exception as ex:
             db_transaction.rollback_transaction()
@@ -505,8 +507,8 @@ class UserBaseModel():
             return invoke_result_data
             
         user_info_model = UserInfoModel(context=self.context)
-        id = self._get_user_info_id(black_info.act_id, black_info.user_id)
-        user_info = user_info_model.get_entity_by_id(id)
+        id_md5 = self._get_user_info_id_md5(black_info.act_id, black_info.user_id)
+        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -527,7 +529,7 @@ class UserBaseModel():
         elif audit_status == 3:
             user_black_model.update_table("audit_status=%s,audit_date=%s", "id=%s", [audit_status, audit_date, black_id])
 
-        self._delete_user_info_cache(user_info.act_id,user_info.id)
+        self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
         
         return invoke_result_data
         
@@ -659,7 +661,7 @@ class UserBaseModel():
                         user_black.refund_order_data = SevenHelper.json_dumps(refund_order_data)
                         user_black.create_date = SevenHelper.get_now_datetime()
                         user_black_model.add_entity(user_black)
-                    self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id"])
+                    self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
         except Exception as ex:
             self.context.logging_link_error("【校验是否拉黑】" + str(ex))
             result = False
